@@ -27,14 +27,14 @@ import logging
 import os
 import pathlib
 import shutil
+import site
 import subprocess
 import sys
 from contextlib import contextmanager
-from typing import TYPE_CHECKING, Any, Callable, Iterator
+from typing import TYPE_CHECKING, Any, Callable, Iterator, TextIO
 
 from ansible_compat.config import ansible_version
 from ansible_compat.prerun import get_cache_dir
-from enrich.console import should_do_markup
 from filelock import FileLock, Timeout
 
 from ansiblelint import cli
@@ -114,13 +114,17 @@ def initialize_options(arguments: list[str] | None = None) -> None:
     if not options.offline:
         options.cache_dir_lock = FileLock(f"{options.cache_dir}/.lock")
         try:
-            options.cache_dir_lock.acquire(timeout=120)
+            options.cache_dir_lock.acquire(timeout=180)
         except Timeout:
             _logger.error(
                 "Timeout waiting for another instance of ansible-lint to release the lock."
             )
             sys.exit(LOCK_TIMEOUT_RC)
 
+    # Avoid extra output noise from Ansible about using devel versions
+    if "ANSIBLE_DEVEL_WARNING" not in os.environ:
+        os.environ["ANSIBLE_DEVEL_WARNING"] = "false"
+
 
 def _do_list(rules: RulesCollection) -> int:
     # On purpose lazy-imports to avoid pre-loading Ansible
@@ -170,6 +174,7 @@ def _do_transform(result: LintResult, opts: Namespace) -> None:
     transformer.run()
 
 
+# pylint: disable=too-many-branches
 def main(argv: list[str] | None = None) -> int:  # noqa: C901
     """Linter CLI entry point."""
     # alter PATH if needed (venv support)
@@ -191,25 +196,19 @@ def main(argv: list[str] | None = None) -> int:  # noqa: C901
     from ansiblelint.rules import RulesCollection
     from ansiblelint.runner import _get_matches
 
-    rules = RulesCollection(options.rulesdirs)
+    rules = RulesCollection(options.rulesdirs, profile=options.profile)
 
     if options.profile == []:
         from ansiblelint.generate_docs import profiles_as_rich
 
         console.print(profiles_as_rich())
         return 0
-    if options.profile:
-        from ansiblelint.rules import filter_rules_with_profile
-
-        filter_rules_with_profile(rules, options.profile[0])
-        # When profile is mentioned, we filter-out the rules based on it
 
     if options.listrules or options.listtags:
         return _do_list(rules)
 
     if isinstance(options.tags, str):
         options.tags = options.tags.split(",")
-
     result = _get_matches(rules, options)
 
     if options.write_list:
@@ -254,6 +253,11 @@ def main(argv: list[str] | None = None) -> int:  # noqa: C901
     if options.cache_dir_lock:
         options.cache_dir_lock.release()
         pathlib.Path(options.cache_dir_lock.lock_file).unlink(missing_ok=True)
+    if options.mock_filters:
+        _logger.warning(
+            "The following filters were mocked during the run: %s",
+            ",".join(options.mock_filters),
+        )
 
     return app.report_outcome(result, mark_as_success=mark_as_success)
 
@@ -272,17 +276,26 @@ def _previous_revision() -> Iterator[None]:
         stdout=subprocess.PIPE,
         stderr=subprocess.DEVNULL,
     ).stdout.strip()
+    _logger.info("Previous revision SHA: %s", revision)
     path = pathlib.Path(worktree_dir)
+    if path.exists():
+        shutil.rmtree(worktree_dir)
     path.mkdir(parents=True, exist_ok=True)
     # Run check will fail if worktree_dir already exists
     # pylint: disable=subprocess-run-check
     subprocess.run(
         ["git", "worktree", "add", "-f", worktree_dir],
+        stdout=subprocess.DEVNULL,
         stderr=subprocess.DEVNULL,
     )
     try:
         with cwd(worktree_dir):
-            subprocess.run(["git", "checkout", revision], check=True)
+            subprocess.run(
+                ["git", "checkout", revision],
+                stdout=subprocess.DEVNULL,
+                stderr=subprocess.DEVNULL,
+                check=True,
+            )
             yield
     finally:
         options.exclude_paths = [abspath(p, os.getcwd()) for p in rel_exclude_paths]
@@ -314,17 +327,75 @@ def path_inject() -> None:
     # This must be run before we do run any subprocesses, and loading config
     # does this as part of the ansible detection.
     paths = [x for x in os.environ.get("PATH", "").split(os.pathsep) if x]
-    ansible_path = shutil.which("ansible")
-    if ansible_path:
-        ansible_path = os.path.dirname(ansible_path)
+    inject_paths = []
+
+    userbase_bin_path = f"{site.getuserbase()}/bin"
+    if userbase_bin_path not in paths and os.path.exists(
+        f"{userbase_bin_path}/bin/ansible"
+    ):
+        inject_paths.append(userbase_bin_path)
+
     py_path = os.path.dirname(sys.executable)
-    # Determine if we need to manipulate PATH
-    for path in (ansible_path, py_path):
-        if path and path not in paths:  # pragma: no cover
-            # tested by test_call_from_outside_venv but coverage cannot detect it
-            paths.insert(0, path)
-            os.environ["PATH"] = os.pathsep.join(paths)
-            print(f"WARNING: PATH altered to include {path}", file=sys.stderr)
+    if py_path not in paths and os.path.exists(f"{py_path}/ansible"):
+        inject_paths.append(py_path)
+
+    if inject_paths:
+        print(
+            f"WARNING: PATH altered to include {', '.join(inject_paths)} :: This is usually a sign of broken local setup, which can cause unexpected behaviors.",
+            file=sys.stderr,
+        )
+        os.environ["PATH"] = os.pathsep.join([*inject_paths, *paths])
+
+    # We do know that finding ansible in PATH does not guarantee that it is
+    # functioning or that is in fact the same version that was installed as
+    # our dependency, but addressing this would be done by ansible-compat.
+    if not shutil.which("ansible"):
+        raise RuntimeError("Failed to find ansible executable in PATH")
+
+
+# Based on Ansible implementation
+def to_bool(value: Any) -> bool:
+    """Return a bool for the arg."""
+    if value is None or isinstance(value, bool):
+        return bool(value)
+    if isinstance(value, str):
+        value = value.lower()
+    if value in ("yes", "on", "1", "true", 1):
+        return True
+    return False
+
+
+def should_do_markup(stream: TextIO = sys.stdout) -> bool:
+    """Decide about use of ANSI colors."""
+    py_colors = None
+
+    # https://xkcd.com/927/
+    for env_var in ["PY_COLORS", "CLICOLOR", "FORCE_COLOR", "ANSIBLE_FORCE_COLOR"]:
+        value = os.environ.get(env_var, None)
+        if value is not None:
+            py_colors = to_bool(value)
+            break
+
+    # If deliberately disabled colors
+    if os.environ.get("NO_COLOR", None):
+        return False
+
+    # User configuration requested colors
+    if py_colors is not None:
+        return to_bool(py_colors)
+
+    term = os.environ.get("TERM", "")
+    if "xterm" in term:
+        return True
+
+    if term == "dumb":
+        return False
+
+    # Use tty detection logic as last resort because there are numerous
+    # factors that can make isatty return a misleading value, including:
+    # - stdin.isatty() is the only one returning true, even on a real terminal
+    # - stderr returning false if user user uses a error stream coloring solution
+    return stream.isatty()
 
 
 if __name__ == "__main__":
