@@ -8,7 +8,7 @@ from ansiblelint.file_utils import Lintable
 from ansiblelint.rules import AnsibleLintRule
 
 # fqcn_builtins was added in 5.1.0 as FQCNBuiltinsRule, renamed to fqcn_builtins in 6.0.0
-from ansiblelint.rules.fqcn_builtins import builtins
+from ansiblelint.rules.fqcn import builtins
 from ansiblelint.skip_utils import is_nested_task
 
 
@@ -58,7 +58,8 @@ if "pytest" in sys.modules:
             "examples/playbooks/rule-only-builtins.yml",
         )
         assert result.returncode == VIOLATIONS_FOUND_RC
-        assert "Finished with 1 failure(s)" in result.stderr
+        assert "Failed" in result.stderr
+        assert "1 failure(s)" in result.stderr
         assert "only-builtins" in result.stdout
 
     @pytest.mark.parametrize(
